@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.11.14"
-#define MARIADB_BASE_VERSION		"mariadb-10.11"
-#define MARIADB_VERSION_ID		101114
+#define MARIADB_CLIENT_VERSION_STR	"11.4.3"
+#define MARIADB_BASE_VERSION		"mariadb-11.4"
+#define MARIADB_VERSION_ID		110403
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                101114
-#define MYSQL_SERVER_VERSION            "10.11.14-MariaDB"
+#define MYSQL_VERSION_ID                110403
+#define MYSQL_SERVER_VERSION            "11.4.3-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.3.17"
-#define MARIADB_PACKAGE_VERSION_ID 30317
+#define MARIADB_PACKAGE_VERSION "3.4.1"
+#define MARIADB_PACKAGE_VERSION_ID 30401
 #define MARIADB_SYSTEM_TYPE "NetBSD"
-#define MARIADB_MACHINE_TYPE "aarch64"
+#define MARIADB_MACHINE_TYPE "powerpc"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
