@@ -127,7 +127,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-#define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
 #define HAVE_INDEX 1
@@ -151,6 +150,7 @@
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
+#define HAVE_GETPAGESIZE 1
 /* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
@@ -195,7 +195,6 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
-#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -255,6 +254,7 @@
 #define HAVE_SOCKADDR_IN6_SIN6_LEN 1
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
+#define STRUCT_TM_HAS_TM_GMTOFF 1
 
 /* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND_MEMCHECK_H */
@@ -377,14 +377,13 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
-#define HAVE_X509_check_host 1
+/* #undef HAVE_X509_check_host */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef NO_FCNTL_NONBLOCK */
-#define NO_ALARM 1
 
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
@@ -402,27 +401,38 @@
 #define SIGNAL_WITH_VIO_CLOSE 1
 
 /* Windows stuff, mostly functions, that have Posix analogs but named differently */
-#ifdef _WIN32
-#define S_IROTH _S_IREAD
-#define S_IFIFO _S_IFIFO
-#define SIGQUIT SIGTERM
-#define SIGPIPE SIGINT
-#define sigset_t int
-#define mode_t int
-#define popen _popen
-#define pclose _pclose
-#define ssize_t SSIZE_T
-#define strcasecmp _stricmp
-#define strncasecmp _strnicmp
-#define strtok_r strtok_s
+/* #undef S_IROTH */
+/* #undef S_IFIFO */
+/* #undef IPPROTO_IPV6 */
+/* #undef IPV6_V6ONLY */
+/* #undef sigset_t */
+/* #undef mode_t */
+/* #undef SIGQUIT */
+/* #undef SIGPIPE */
+/* #undef popen */
+/* #undef pclose */
+/* #undef ssize_t */
+/* #undef strcasecmp */
+/* #undef strncasecmp */
+/* #undef snprintf */
+/* #undef strtok_r */
+/* #undef strtoll */
+/* #undef strtoull */
+/* #undef vsnprintf */
+#if defined(_MSC_VER) && (_MSC_VER > 1800)
 #define tzname _tzname
 #define P_tmpdir "C:\\TEMP"
+#endif
+#if defined(_MSC_VER) && (_MSC_VER > 1310)
+# define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
+#endif
+#define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
-#define HAVE_SETENV
+/* We don't want the min/max macros */
+#ifdef _WIN32
 #define NOMINMAX 1
-#define PSAPI_VERSION 2     /* for GetProcessMemoryInfo() */
-#endif /* _WIN32 */
+#endif
 
 /*
   MySQL features
@@ -446,11 +456,6 @@
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
 
-/* Whether an anonymous private mapping is unaccessible after
-madvise(MADV_DONTNEED) or madvise(MADV_FREE) or similar has been invoked;
-this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
-/* #undef HAVE_UNACCESSIBLE_AFTER_MEM_DECOMMIT */
-
 #define HAVE_CHARSET_armscii8 1
 #define HAVE_CHARSET_ascii 1
 #define HAVE_CHARSET_big5 1
@@ -494,6 +499,7 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
 #define HAVE_des 1
+#define HAVE_hkdf 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -524,18 +530,18 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 
 /* #undef SO_EXT */
 
-#define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 11
-#define MYSQL_VERSION_PATCH 14
+#define MYSQL_VERSION_MAJOR 11
+#define MYSQL_VERSION_MINOR 4
+#define MYSQL_VERSION_PATCH 3
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.11.14"
+#define PACKAGE_STRING "MySQL Server 11.4.3"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.11.14"
-#define VERSION "10.11.14"
+#define PACKAGE_VERSION "11.4.3"
+#define VERSION "11.4.3"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -549,6 +555,7 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 #ifndef EMBEDDED_LIBRARY
 /* #undef WSREP_INTERFACE_VERSION */
 /* #undef WITH_WSREP */
+/* #undef WSREP_PROC_INFO */
 #endif
 
 #if !defined(__STDC_FORMAT_MACROS)
